Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(417)

Unified Diff: third_party/WebKit/Source/core/html/HTMLPlugInElement.h

Issue 2845583002: Remove FrameViewBase as base class of RemoteFrameView. (Closed)
Patch Set: fix scrollbar inactive Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLPlugInElement.h
diff --git a/third_party/WebKit/Source/core/html/HTMLPlugInElement.h b/third_party/WebKit/Source/core/html/HTMLPlugInElement.h
index 5932b286a897ef8ed069a3ab2ab1b37727549ac7..7cec4831184a423bcb327b988713e0eb755ed935 100644
--- a/third_party/WebKit/Source/core/html/HTMLPlugInElement.h
+++ b/third_party/WebKit/Source/core/html/HTMLPlugInElement.h
@@ -51,14 +51,14 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
// TODO(dcheng): Consider removing this, since HTMLEmbedElementLegacyCall
// and HTMLObjectElementLegacyCall usage is extremely low.
SharedPersistent<v8::Object>* PluginWrapper();
// TODO(joelhockey): Clean up pluginWidget and plugin (maybe also
// pluginWrapper). It would be good to remove and/or rename some of these.
// pluginWidget and plugin both return the plugin that is stored on this
// element. However pluginWidget will synchronously create the plugin if
// required by calling layoutPartForJSBindings. Possibly the pluginWidget
// code can be inlined into pluginWrapper.
PluginView* PluginWidget() const;
- PluginView* Plugin() const;
+ PluginView* OwnedPlugin() const;
bool CanProcessDrag() const;
const String& Url() const { return url_; }
@@ -165,8 +165,6 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
bool AllowedToLoadObject(const KURL&, const String& mime_type);
bool WouldLoadAsNetscapePlugin(const String& url, const String& service_type);
- void SetPlugin(PluginView*);
- PluginView* ReleasePlugin();
joelhockey 2017/05/01 23:04:35 These specialized PluginView methods are no longer
void SetPersistedPlugin(PluginView*);
bool RequestObjectInternal(const String& url,
@@ -182,11 +180,10 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
// avoid accessing |layoutObject()| in layoutObjectIsFocusable().
bool plugin_is_available_ = false;
- Member<PluginView> plugin_;
- // Normally the plugin is stored in HTMLFrameOwnerElement::m_widget.
+ // Normally the plugin is stored in HTMLFrameOwnerElement::widget_.
// However, plugins can persist even when not rendered. In order to
- // prevent confusing code which may assume that ownedWidget() != null
- // means the frame is active, we save off m_widget here while
+ // prevent confusing code which may assume that OwnedWidget() != null
+ // means the frame is active, we save off widget_ here while
// the plugin is persisting but not being displayed.
Member<PluginView> persisted_plugin_;
};
@@ -51,14 +51,14 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
// and HTMLObjectElementLegacyCall usage is extremely low.
SharedPersistent<v8::Object>* PluginWrapper();
- // TODO(joelhockey): Clean up pluginWidget and plugin (maybe also
- // pluginWrapper). It would be good to remove and/or rename some of these.
- // pluginWidget and plugin both return the plugin that is stored on this
- // element. However pluginWidget will synchronously create the plugin if
- // required by calling layoutPartForJSBindings. Possibly the pluginWidget
- // code can be inlined into pluginWrapper.
+ // TODO(joelhockey): Clean up PluginWidget and OwnedPlugin (maybe also
+ // PluginWrapper). It would be good to remove and/or rename some of these.
+ // PluginWidget and OwnedPlugin both return the plugin that is stored as
+ // widget in HTMLFrameOwnerElement. However PluginWidget will synchronously
+ // create the plugin if required by calling LayoutPartForJSBindings.
+ // Possibly the PluginWidget code can be inlined into PluginWrapper.
PluginView* PluginWidget() const;

Powered by Google App Engine
This is Rietveld 408576698